View source: R/PanelMatchObject.R
| all.equal.PanelMatch | R Documentation |
all.equal.PanelMatch compares two PanelMatch objects using
the standard all.equal() semantics. The comparison is recursive, so
the matched sets, the attributes attached to individual matched control
vectors (for example, weights and distances), the attributes of the
matched.set objects, and the specification metadata stored on the
PanelMatch object are all compared.
## S3 method for class 'PanelMatch'
all.equal(target, current, ...)
target |
A |
current |
A |
... |
Additional arguments passed to the next |
Comparison is order-sensitive. Thus, two PanelMatch objects that
contain the same matched controls in a different order are not considered
equal. Numeric values are compared using the tolerance supported by
all.equal().
For a single logical result, use
isTRUE(all.equal(x, y)). Use identical(x, y) instead when an
exact representation-level comparison is required.
TRUE if the objects are equal; otherwise, a character vector
describing the differences.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.