Learn R Programming

PanelMatch (version 3.1.5)

all.equal.PanelMatch: Compare PanelMatch objects

Description

all.equal.PanelMatch compares two PanelMatch objects using the standard all.equal() semantics. The comparison is recursive, so the matched sets, the attributes attached to individual matched control vectors (for example, weights and distances), the attributes of the matched.set objects, and the specification metadata stored on the PanelMatch object are all compared.

Usage

# S3 method for PanelMatch
all.equal(target, current, ...)

Value

TRUE if the objects are equal; otherwise, a character vector describing the differences.

Arguments

target

A PanelMatch object.

current

A PanelMatch object to compare with target.

...

Additional arguments passed to the next all.equal method, such as tolerance.

Details

Comparison is order-sensitive. Thus, two PanelMatch objects that contain the same matched controls in a different order are not considered equal. Numeric values are compared using the tolerance supported by all.equal().

For a single logical result, use isTRUE(all.equal(x, y)). Use identical(x, y) instead when an exact representation-level comparison is required.